@@ -47,12 +47,12 @@
 #define R__USE_IMT   /**/
 #undef R__COMPLETE_MEM_TERMINATION /**/
 #undef R__HAS_CEFWEB  /**/
-#undef R__HAS_QT5WEB  /**/
+#undef R__HAS_QT6WEB  /**/
 #define R__HAS_DAVIX  /**/
 #define R__HAS_DATAFRAME /**/
 #define R__HAS_ROOT7 /**/
 #undef R__LESS_INCLUDES /**/
-#define R__HAS_TBB /**/
+#undef R__HAS_TBB /**/
 
 #if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
 #ifndef VECCORE_ENABLE_VC
@@ -64,7 +64,7 @@
 #define R__HAS_DEFAULT_ZLIB  /**/
 #undef R__HAS_DEFAULT_LZMA  /**/
 #undef R__HAS_DEFAULT_ZSTD  /**/
-#undef R__HAS_CLOUDFLARE_ZLIB /**/
+#define R__HAS_CLOUDFLARE_ZLIB /**/
 
 #define R__HAS_TMVACPU /**/
 #undef R__HAS_TMVAGPU /**/
